@@ -4,6 +4,7 @@ from enum import Enum
 class OrderType(Enum):
     LIMIT = 'LIMIT'
     MARKET = 'MARKET'
+    STOP_LOSS_LIMIT = "STOP_LOSS_LIMIT"
 
     @staticmethod
     def from_string(value: str):
@@ -28,9 +29,4 @@ class OrderType(Enum):
         return OrderType.from_string(value)
 
     def equals(self, other):
-
-        if isinstance(other, Enum):
-            return self.value == other.value
-
-        else:
-            return OrderType.from_string(other) == self
+        return OrderType.from_value(other) == self
