@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+
 from investing_algorithm_framework.core.exceptions import OperationalException
 from investing_algorithm_framework.core.models import OrderSide, OrderType
 
@@ -7,12 +8,12 @@ class OrderValidator(ABC):
 
     def validate(self, order, portfolio):
 
-        if OrderSide.BUY.equals(order.order_side):
+        if OrderSide.BUY.equals(order.side):
             self.validate_buy_order(order, portfolio)
         else:
             self.validate_sell_order(order, portfolio)
 
-        if OrderType.LIMIT.equals(order.order_type):
+        if OrderType.LIMIT.equals(order.type):
             self.validate_limit_order(order, portfolio)
         else:
             self.validate_market_order(order, portfolio)
@@ -21,17 +22,14 @@ class OrderValidator(ABC):
 
     def validate_sell_order(self, order, portfolio):
 
-        position = portfolio.positions\
-            .filter_by(portfolio=portfolio)\
-            .filter_by(symbol=order.target_symbol)\
-            .first()
-
+        position = portfolio.get_position(order.get_target_symbol())
+    
         if position is None:
             raise OperationalException(
                 "Can't add sell order to non existing position"
             )
 
-        if OrderType.LIMIT.equals(order.order_type):
+        if OrderType.LIMIT.equals(order.type):
             if position.amount < order.amount_target_symbol:
                 raise OperationalException(
                     "Order amount is larger then amount of open position"
@@ -52,7 +50,7 @@ class OrderValidator(ABC):
     @staticmethod
     def validate_buy_order(order, portfolio):
 
-        if not order.trading_symbol == portfolio.trading_symbol:
+        if not order.get_trading_symbol() == portfolio.get_trading_symbol():
             raise OperationalException(
                 f"Can't add buy order with trading "
                 f"symbol {order.trading_symbol} to "
@@ -61,20 +59,20 @@ class OrderValidator(ABC):
 
     @staticmethod
     def validate_limit_order(order, portfolio):
+        total_price = order.get_amount_target_symbol() * order.get_price()
+        unallocated = portfolio.get_unallocated()
 
-        total_price = order.amount_target_symbol * order.initial_price
-
-        if float(portfolio.unallocated) < total_price:
+        if unallocated.get_amount() < total_price:
             raise OperationalException(
                 f"Order total: {total_price} {portfolio.trading_symbol}, is "
-                f"larger then unallocated size: {portfolio.unallocated} "
+                f"larger then unallocated size: {unallocated.get_amount()} "
                 f"{portfolio.trading_symbol} of the portfolio"
             )
 
     @staticmethod
     def validate_market_order(order, portfolio):
 
-        if OrderSide.BUY.equals(order.order_side):
+        if OrderSide.BUY.equals(order.side):
 
             if order.amount_trading_symbol is None:
                 raise OperationalException(
@@ -90,9 +88,7 @@ class OrderValidator(ABC):
                     f"{portfolio.trading_symbol.upper()}"
                 )
         else:
-            position = portfolio.positions\
-                .filter_by(symbol=order.target_symbol)\
-                .first()
+            position = portfolio.get_position(order.get_target_symbol())
 
             if position is None:
                 raise OperationalException(
